@@ -29,9 +29,9 @@ class FALKON_EXPORT BookmarksItemDelegate : public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    explicit BookmarksItemDelegate(QTreeView* parent = 0);
+    explicit BookmarksItemDelegate(QTreeView* parent = nullptr);
 
-    void paint(QPainter* painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    void paint(QPainter* painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
 private:
     QTreeView* m_tree;
