@@ -35,13 +35,7 @@ class DownloadItem;
 }
 
 class QListWidgetItem;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-class QWebEngineDownloadItem;
-#define Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS QWebEngineDownloadItem
-#else
 class QWebEngineDownloadRequest;
-#define Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS QWebEngineDownloadRequest
-#endif
 
 class DownloadManager;
 
@@ -50,7 +44,7 @@ class FALKON_EXPORT DownloadItem : public QWidget
     Q_OBJECT
 
 public:
-    explicit DownloadItem(QListWidgetItem* item, Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS* downloadItem, const QString &path, const QString &fileName, bool openFile, DownloadManager* manager);
+    explicit DownloadItem(QListWidgetItem* item, QWebEngineDownloadRequest* downloadItem, const QString &path, const QString &fileName, bool openFile, DownloadManager* manager);
     bool isDownloading() const { return m_downloading; }
     bool isCancelled();
     QTime remainingTime() const { return m_remTime; }
@@ -75,11 +69,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void parentResized(const QSize &size);
     void finished();
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    void downloadProgress(qint64 received, qint64 total);
-#else
     void receivedOrTotalBytesChanged();
-#endif
     void stop();
     void pauseResume();
     void openFile();
@@ -96,7 +86,7 @@ private:
     Ui::DownloadItem* ui;
 
     QListWidgetItem* m_item;
-    Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS* m_download;
+    QWebEngineDownloadRequest* m_download;
     QString m_path;
     QString m_fileName;
     QElapsedTimer m_downTimer;
